Package: ggblanket
Title: Simplify 'ggplot2' Visualisation
Version: 10.0.0
Authors@R: 
    person("David", "Hodge", , "davidhodge931@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-3868-7501"))
Description: Simplify 'ggplot2' visualisation with 'ggblanket' wrapper
    functions.
License: MIT + file LICENSE
URL: https://davidhodge931.github.io/ggblanket/,
        https://github.com/davidhodge931/ggblanket
BugReports: https://github.com/davidhodge931/ggblanket/issues
Imports: colorspace, dplyr (>= 1.0.4), farver, forcats, ggplot2 (>=
        3.5.0), grid, hms (>= 0.5.0), labelled, lubridate (>= 1.7.8),
        magrittr, purrr, rlang (>= 1.1.0), scales (>= 1.3.0),
        snakecase, stringr (>= 1.3.0), tidyr (>= 1.0.0), tidyselect (>=
        1.2.0), viridisLite
Suggests: spelling, hexbin, isoband, knitr, palmerpenguins, patchwork,
        quantreg, rmarkdown, sf, testthat (>= 3.0.0), tibble, vdiffr,
        viridis
VignetteBuilder: knitr
Config/Needs/website: concaveman, corrr, farver, ggbeeswarm, ggblend,
        ggdensity, ggdist, ggeasy, ggforce, ggh4x, gghighlight,
        ggnewscale, ggrepel, ggridges, ggpattern, glue, marquee,
        paletteer, showtext, sysfonts
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.1
Author: David Hodge [aut, cre, cph] (<https://orcid.org/0000-0002-3868-7501>)
Maintainer: David Hodge <davidhodge931@gmail.com>
Built: R 4.4.1; ; 2024-07-27 19:37:16 UTC; unix
