# Generated by roxygen2: do not edit by hand

export("%>%")
export(aes_colour_contrast)
export(aes_colour_darken)
export(aes_colour_lighten)
export(aes_fill_darken)
export(aes_fill_lighten)
export(blue)
export(dark_mode_b)
export(dark_mode_r)
export(dark_mode_t)
export(darkness)
export(gg_area)
export(gg_bar)
export(gg_bin_2d)
export(gg_blanket)
export(gg_boxplot)
export(gg_col)
export(gg_contour)
export(gg_contour_filled)
export(gg_crossbar)
export(gg_density)
export(gg_density_2d)
export(gg_density_2d_filled)
export(gg_errorbar)
export(gg_freqpoly)
export(gg_function)
export(gg_hex)
export(gg_histogram)
export(gg_jitter)
export(gg_label)
export(gg_line)
export(gg_linerange)
export(gg_path)
export(gg_point)
export(gg_pointrange)
export(gg_polygon)
export(gg_qq)
export(gg_quantile)
export(gg_raster)
export(gg_rect)
export(gg_ribbon)
export(gg_rug)
export(gg_segment)
export(gg_sf)
export(gg_smooth)
export(gg_step)
export(gg_text)
export(gg_tile)
export(gg_violin)
export(grey)
export(jumble)
export(light_mode_b)
export(light_mode_r)
export(light_mode_t)
export(lightness)
export(linewidthness)
export(mode_orientation_to_x)
export(mode_orientation_to_y)
export(navy)
export(orange)
export(pink)
export(purple)
export(red)
export(set_blanket)
export(teal)
export(weave_col_palette_c)
export(weave_col_palette_d)
export(weave_col_palette_o)
export(weave_geom_defaults)
export(weave_mode)
export(weave_theme)
importFrom(magrittr,"%>%")
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
importFrom(rlang,.data)
